@@ -3,20 +3,22 @@
 
 int main(int argc, char *argv[])
 {
-    QApplication::setApplicationName("Sticky Notes");
+    QApplication app(argc, argv);
+
+    QApplication::addLibraryPath("./plugins");
+    QApplication::setApplicationName("Puzzle Master");
     QApplication::setOrganizationName("Venemo");
     // APP_VERSION is defined in the .pro file
     QApplication::setApplicationVersion(QString(APP_VERSION));
 
-    QApplication a(argc, argv);
     qsrand((uint)QTime::currentTime().msec());
 
     MainWindow w;
-#if defined(Q_WS_S60)
+#if defined(MOBILE)
     w.showMaximized();
 #else
     w.show();
 #endif
 
-    return a.exec();
+    return app.exec();
 }
