@@ -14,7 +14,7 @@
 #define SETTING_ROWS "Rows"
 #define SETTING_COLS "Columns"
 
-#if defined(Q_WS_MAEMO_5) || defined(Q_WS_S60) || defined(Q_WS_WINCE)
+#if defined(MOBILE)
 #define DEFAULT_TOLERANCE 10
 #else
 #define DEFAULT_TOLERANCE 5
@@ -26,19 +26,30 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
     _boardBackground(boardBackground())
 {
     ui->setupUi(this);
-#if defined(Q_WS_MAEMO_5) || defined(Q_WS_S60)
-    setFixedWidth(parentWidget()->width());
-
+#if defined(Q_WS_MAEMO_5)
     // This ensures the correct look on Maemo 5 too
     QDialogButtonBox *buttonBox = new QDialogButtonBox(Qt::Vertical, this);
     ui->btnClose->setDefault(true);
     buttonBox->addButton(ui->btnClose, QDialogButtonBox::ActionRole);
     layout()->addWidget(buttonBox);
 #else
-    setFixedHeight(height() - ui->chkAccelerometer->height());
     setFixedWidth(450);
+#endif
+
+#if defined(HAVE_QACCELEROMETER)
+#else
+    // Deleting the relevant UI if we don't have an accelerometer
+    setFixedHeight(height() - ui->chkAccelerometer->height());
     ui->chkAccelerometer->deleteLater();
 #endif
+
+#if QT_VERSION >= QT_VERSION_CHECK(4, 6, 0)
+#else
+    // Deleting the relevant UI if we don't have Qt 4.6 at least
+    setFixedHeight(height() - ui->chkUseDropshadow->height());
+    ui->chkUseDropshadow->deleteLater();
+#endif
+
     connect(this, SIGNAL(accepted()), this, SLOT(saveSettings()));
     connect(this, SIGNAL(rejected()), this, SLOT(saveSettings()));
 }
@@ -54,9 +65,11 @@ void SettingsDialog::saveSettings()
     QSettings s;
     s.setValue(SETTING_COLS, ui->cbColumns->currentIndex() + 2);
     s.setValue(SETTING_ROWS, ui->cbRows->currentIndex() + 2);
-    s.setValue(SETTING_USE_DROPSHADOW, ui->chkUseDropshadow->isChecked());
     s.setValue(SETTING_BOARDBACKGROUND, _boardBackground);
     s.setValue(SETTING_TOLERANCE, (ui->cbTolerance->currentIndex() + 1) * 5);
+#if QT_VERSION >= QT_VERSION_CHECK(4, 6, 0)
+    s.setValue(SETTING_USE_DROPSHADOW, ui->chkUseDropshadow->isChecked());
+#endif
 #if defined(Q_WS_MAEMO_5) || defined(Q_WS_S60)
     s.setValue(SETTING_USE_ACCELEROMETER, ui->chkAccelerometer->isChecked());
 #endif
@@ -70,10 +83,12 @@ void SettingsDialog::on_btnClose_clicked()
 
 void SettingsDialog::showEvent(QShowEvent *e)
 {
-#if defined(Q_WS_MAEMO_5) || defined(Q_WS_S60)
+#if QT_VERSION >= QT_VERSION_CHECK(4, 6, 0)
+    ui->chkUseDropshadow->setChecked(useDropShadow());
+#endif
+#if defined(HAVE_QACCELEROMETER)
     ui->chkAccelerometer->setChecked(useAccelerometer());
 #endif
-    ui->chkUseDropshadow->setChecked(useDropShadow());
     int r = CLAMP(rows(), 2, 15), c = CLAMP(columns(), 2, 15);
     ui->cbRows->setCurrentIndex(r - 2);
     ui->cbColumns->setCurrentIndex(c - 2);
@@ -103,6 +118,14 @@ void SettingsDialog::on_btnBoardColor_clicked()
     }
 }
 
+#if QT_VERSION >= QT_VERSION_CHECK(4, 6, 0)
+bool SettingsDialog::useDropShadow()
+{
+    QSettings s;
+    return s.value(SETTING_USE_DROPSHADOW, true).toBool();
+}
+#endif
+
 bool SettingsDialog::useAccelerometer()
 {
     QSettings s;
@@ -128,12 +151,6 @@ int SettingsDialog::columns()
     return s.value(SETTING_COLS, 3).toInt();
 }
 
-bool SettingsDialog::useDropShadow()
-{
-    QSettings s;
-    return s.value(SETTING_USE_DROPSHADOW, true).toBool();
-}
-
 QColor SettingsDialog::boardBackground()
 {
     QSettings s;
